@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     ogrinfo.py
@@ -21,11 +19,6 @@ __author__ = 'Victor Olaya'
 __date__ = 'November 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 
-# This will get replaced with a git SHA1 when you do a git archive
-
-__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
-
-
 from qgis.core import (QgsProcessingException,
                        QgsProcessingParameterVectorLayer,
                        QgsProcessingParameterBoolean,
@@ -35,7 +28,6 @@ from processing.algs.gdal.GdalUtils import GdalUtils
 
 
 class ogrinfo(GdalAlgorithm):
-
     INPUT = 'INPUT'
     SUMMARY_ONLY = 'SUMMARY_ONLY'
     NO_METADATA = 'NO_METADATA'
@@ -76,25 +68,30 @@ class ogrinfo(GdalAlgorithm):
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
         arguments = ['-al']
 
-        if self.parameterAsBool(parameters, self.SUMMARY_ONLY, context):
+        if self.parameterAsBoolean(parameters, self.SUMMARY_ONLY, context):
             arguments.append('-so')
-        if self.parameterAsBool(parameters, self.NO_METADATA, context):
+        if self.parameterAsBoolean(parameters, self.NO_METADATA, context):
             arguments.append('-nomd')
 
         inLayer = self.parameterAsVectorLayer(parameters, self.INPUT, context)
         if inLayer is None:
             raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
 
-        connectionString = GdalUtils.ogrConnectionStringFromLayer(inLayer)
-        arguments.append(connectionString)
+        input_details = self.getOgrCompatibleSource(self.INPUT, parameters, context, feedback, executing)
+        arguments.append(input_details.connection_string)
+        arguments.append(input_details.layer_name)
+
+        if input_details.open_options:
+            arguments.extend(input_details.open_options_as_arguments())
+
         return [self.commandName(), GdalUtils.escapeAndJoin(arguments)]
 
     def processAlgorithm(self, parameters, context, feedback):
-        GdalUtils.runGdal(self.getConsoleCommands(parameters, context, feedback), feedback)
+        console_output = GdalUtils.runGdal(self.getConsoleCommands(parameters, context, feedback), feedback)
         output = self.parameterAsFileOutput(parameters, self.OUTPUT, context)
         with open(output, 'w') as f:
             f.write('<pre>')
-            for s in GdalUtils.getConsoleOutput()[1:]:
+            for s in console_output[1:]:
                 f.write(str(s))
             f.write('</pre>')
 
